;;; batch.el --- Batch Emacs test for org-ehtml

;;; Instructions:
;;
;; 1. Edit the `org-ehtml-load-paths' paths below to point to the
;;    related resources on your system.
;;    
;; 2. Launch an Emacs process which will load this configuration and
;;    only this configuration using the -Q option as follows
;;
;;      emacs -Q -l batch.el
;; 
;; 3. You will now be serving the example test files on port 3333.
;;    Browse to http://localhost:3333/simple.org and try to perform an
;;    edit through the web interface.
;;
;; 4. If the edit works then everything is working as expected, if for
;;    some reason the edit doesn't work, look through the output in
;;    your *Messages* buffer following the "start-relevant-output"
;;    line, and see if anything looks suspicious or send this output
;;    to the list.

;;; Code:
(defvar org-ehtml-load-paths
  '("path/to/elnode"
    "path/to/org-mode/lisp"
    "path/to/org-mode/contrib/lisp"
    "path/to/org-ehtml/src"
    "path/to/org-ehtml/test/lisp")
  "Update these paths to set your load path.")

(mapc (lambda (path) (add-to-list 'load-path path))
      org-ehtml-load-paths)

(require 'test-org-ehtml)

(setq
 debug-on-error t                 ;; show debug info for any errors
 org-e-html-postamble nil         ;; don't export a postamble
 elnode-error-log-to-messages nil ;; stifle unhelpful & noisy elnode warnings
 org-ehtml-docroot test-org-ehtml-example-dir
 org-ehtml-port 3333)

;; stop the default org-ehtml server
(elnode-stop 8000)
(elnode-start 'org-ehtml-handler :port org-ehtml-port)

;; redefine `org-ehtml-edit-handler' with more debug output
(defun org-ehtml-edit-handler (httpcon)
  (let* ((params (elnode-http-params httpcon))
         (path       (substring (cdr (assoc "path" params)) 1))
         (beg (string-to-number (cdr (assoc "beg"  params))))
         (end (string-to-number (cdr (assoc "end"  params))))
         (org                   (cdr (assoc "org"  params))))
    (message "params:%S" params)
    (message "org:%S" org)
    (org-babel-with-temp-filebuffer (expand-file-name path org-ehtml-docroot)
      (let ((orig (buffer-string)))
        (replace-region beg end org)
        (if (run-hook-with-args-until-failure 'org-ehtml-before-save-hook)
            (save-buffer)
          (replace-region (point-min) (point-max) orig)
          (elnode-send-500 httpcon "edit failed `org-ehtml-before-save-hook'")))
      (run-hooks 'org-ehtml-after-save-hook))
    (elnode-http-start httpcon "200" '("Content-type" . "text/html"))
    (elnode-http-return httpcon
      (org-export-string org 'html org-ehtml-docroot))))

;; switch to the *Messages* buffer
(switch-to-buffer "*Messages*")
(message "---------------------start-relevant-output---------------------")
